def jpg(text,res):
    with open(f"{res}.jpg", "wb") as f:
        f.write(text)
    return f

def png(text,res):
    with open(f"{res}.png", "wb") as f:
        f.write(text)
    return f

def webp(text,res):
    with open(f"{res}.webp", "wb") as f:
        f.write(text)
    return f


import img
import req

# genp.logo('Sunset')
def logo(prompt):
    """**this function make a logo with your prompt! use like this:** ```genp.logo('sun')``` **and result is** ```logo.jpg``` **!**"""
    prompt = prompt.replace(' ','%20')
    return img.jpg(req.req(f"https://api.daradege.ir/logo?text={prompt}").content,"logo")

# genp.image('Sunrise')
def image(prompt):
    """**this function make a logo with your prompt! use like this:** ```genp.image('sun')``` **and result is** ```image.jpg``` **!**"""
    prompt = prompt.replace(' ','%20')
    return img.jpg(req.req(f"https://api.daradege.ir/image?text={prompt}").content,"image")
    
# genp.qr('Hello World')
def qr(text):
    """**this function make a logo with your prompt! use like this:** ```genp.qr('sun')``` **and result is** ```qr.jpg``` **!**"""
    text = text.replace(' ','%20')
    return img.jpg(req.req(f"https://api.daradege.ir/qrcode?text={text}").content,"qr")


import requests

def req(url):
    response = requests.get(url)
    if response.status_code == 200:
        return response
    else:
        return f"{response.status_code} | cannot give content from daradegeapi."
